@@ -9,6 +9,7 @@ import unittest
 import numpy as np
 from omnixai.data.tabular import Tabular
 from omnixai.explainers.data.imbalance import ImbalanceAnalyzer
+from omnixai.explanations.base import ExplanationBase
 
 
 class TestImbalance(unittest.TestCase):
@@ -42,6 +43,10 @@ class TestImbalance(unittest.TestCase):
         explanations = explainer.explain(features=["Sex", "Race"])
         explanations.plot()
 
+        s = explanations.to_json()
+        e = ExplanationBase.from_json(s)
+        self.assertEqual(s, e.to_json())
+
 
 if __name__ == "__main__":
     unittest.main()
